Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5317)

Unified Diff: chrome/browser/chromeos/arc/extensions/arc_support_message_host.cc

Issue 2507073002: Split ArcSessionManager from ArcAuthService. (Closed)
Patch Set: Fix rebase mistake Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/arc/extensions/arc_support_message_host.cc
diff --git a/chrome/browser/chromeos/arc/extensions/arc_support_message_host.cc b/chrome/browser/chromeos/arc/extensions/arc_support_message_host.cc
index 2ba2e99e80e418ce3c9c8d3e231058552ec9cfd2..c31f81842283143dce68acb872828bf4092cf1b0 100644
--- a/chrome/browser/chromeos/arc/extensions/arc_support_message_host.cc
+++ b/chrome/browser/chromeos/arc/extensions/arc_support_message_host.cc
@@ -7,7 +7,7 @@
#include "base/json/json_reader.h"
#include "base/json/json_writer.h"
#include "base/threading/thread_task_runner_handle.h"
-#include "chrome/browser/chromeos/arc/arc_auth_service.h"
+#include "chrome/browser/chromeos/arc/arc_session_manager.h"
#include "chrome/browser/chromeos/arc/arc_support_host.h"
namespace arc {
@@ -27,13 +27,13 @@ std::unique_ptr<extensions::NativeMessageHost> ArcSupportMessageHost::Create() {
ArcSupportMessageHost::ArcSupportMessageHost() = default;
ArcSupportMessageHost::~ArcSupportMessageHost() {
// On shutdown, ArcAuthService may be already deleted. In that case,
// ArcAuthService::Get() returns nullptr. Note that, ArcSupportHost
// disconnects to this instance on shutdown already.
- ArcAuthService* auth_service = ArcAuthService::Get();
- if (auth_service) {
- DCHECK(auth_service->support_host());
- auth_service->support_host()->UnsetMessageHost(this);
+ ArcSessionManager* arc_session_manager = ArcSessionManager::Get();
+ if (arc_session_manager) {
+ DCHECK(arc_session_manager->support_host());
+ arc_session_manager->support_host()->UnsetMessageHost(this);
}
}
@@ -58,10 +58,10 @@ void ArcSupportMessageHost::Start(Client* client) {
DCHECK(!client_);
client_ = client;
- ArcAuthService* auth_service = ArcAuthService::Get();
- DCHECK(auth_service);
- DCHECK(auth_service->support_host());
- auth_service->support_host()->SetMessageHost(this);
+ ArcSessionManager* arc_session_manager = ArcSessionManager::Get();
+ DCHECK(arc_session_manager);
+ DCHECK(arc_session_manager->support_host());
+ arc_session_manager->support_host()->SetMessageHost(this);
}
void ArcSupportMessageHost::OnMessage(const std::string& message_string) {
@@ -27,13 +27,13 @@ std::unique_ptr<extensions::NativeMessageHost> ArcSupportMessageHost::Create() {
ArcSupportMessageHost::ArcSupportMessageHost() = default;
ArcSupportMessageHost::~ArcSupportMessageHost() {
- // On shutdown, ArcAuthService may be already deleted. In that case,
- // ArcAuthService::Get() returns nullptr. Note that, ArcSupportHost
+ // On shutdown, ArcSessionManager may be already deleted. In that case,
+ // ArcSessionManager::Get() returns nullptr. Note that, ArcSupportHost
// disconnects to this instance on shutdown already.

Powered by Google App Engine
This is Rietveld 408576698